#!/bin/bash
#
# Amendment History
# =================
# inital (RB)
#

if ! test -z $DEBUG && test $DEBUG=1; then set -vx; fi # DEBUG CHECK

source /backups/patch/settings.sh

audit() {
 audit_date=`date "+%d%m%y %T"`
 echo "$audit_date : $1" >> $AUDIT_LOG
}

cleanup() {
 audit "patch clean up"
 cd $PATCHBASE
 rm -rf .* 2>/dev/null
 rm -rf * 2>/dev/null
 echo; echo "Clean up done..."

}

heading() {
 clear
 echo "${inv} Swivel Maintenance (c) $COPYRIGHT_YEAR${nor}                                             ${inv}$PINSAFE_TYPE${nor}"
 echo
 echo $1
 echo
}

yorn() {
 echo
 echo -n "Are you sure? (Yes/No): "
 read yn
 check_ans $1 $yn
}

check_ans() {
 if test ! $2; then
  $1; fi
 if test ! $2 = "Yes" && test ! $2 = "yes" && test ! $2 = "y" && test ! $2 = "Y" ; then
  $1; fi
}

warning() {
 heading "Upgrading Swivel Appliance"
 echo "Continuing will apply patch ${inv}$PATCH_VER${nor}."
 echo
 echo "The system should not be providing authentication whilst the patch is applied."
 yorn exit
}


upgrade_rpm() {
    heading "Swivel Appliance bash patch"
    echo "Please wait, installing Appliance bash update."
    rpm --import RPM-GPG-KEY-Swivel
    rpm --force -Uh *.rpm
    if [ $? -eq 0 ]; then 
	echo
	echo "Update applied, there is no need to reboot the Appliance."
	audit "Updated rpm"
    else
	echo
	echo "Appliance already patched."
        audit "Appliance already patched"
    fi
    echo; read -p "Press Return to continue" yn
}

patch_tomcat() {
    heading "Swivel Appliance tomcat patch"
    audit "tomcat server.xml patch"
    cp $TOMCAT_PATH/conf/server.xml $TOMCAT_PATH/conf/server.xml.orginal
    sed -i 's/sslProtocol*=/sslProtocols=/g' $TOMCAT_PATH/conf/server.xml
    sed -i 's/="TLS"/="TLSv1,TLSv1.1,TLSv1.2"/g' $TOMCAT_PATH/conf/server.xml
    sed -i '/ciphers=/c\\t    ciphers="TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256,TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA,TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384,TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA,TLS_ECDHE_RSA_WITH_RC4_128_SHA,TLS_RSA_WITH_AES_128_CBC_SHA256,TLS_RSA_WITH_AES_128_CBC_SHA,TLS_RSA_WITH_AES_256_CBC_SHA256,TLS_RSA_WITH_AES_256_CBC_SHA,SSL_RSA_WITH_RC4_128_SHA"' $TOMCAT_PATH/conf/server.xml
    echo "Updated applied, IMPORTANT: You will need to restart Tomcat to action changes."
    echo; read -p "Press Return to continue" yn
}

patch_webmin() {
    heading "Swivel Appliance webmin patch"
    audit "webmin miniserv.conf patch"
    cp /etc/webmin/miniserv.conf /etc/webmin/miniserv.conf.orginal
    sed -i '/ssl_cipher_list=/d' /etc/webmin/miniserv.conf
    echo 'ssl_cipher_list=ECDHE-RSA-AES256-SHA384:AES256-SHA256:AES256-SHA256:RC4:HIGH:MEDIUM:+TLSv1:!MD5:!SSLv2:+SSLv3:!ADH:!aNULL:!eNULL:!NULL:!DH:!ADH:!EDH:!AESGCM' >> /etc/webmin/miniserv.conf
    sed -i '/ssl_version=/d' /etc/webmin/miniserv.conf
    echo 'ssl_version=10' >> /etc/webmin/miniserv.conf
    service webmin restart
    echo "Updated applied."
    echo; read -p "Press Return to continue" yn
}

heading "Swivel Appliance update"
audit "Applying patch: $PATCH_VER"
upgrade_rpm
patch_webmin
patch_tomcat
cleanup
